@@ -133,7 +133,7 @@ public:
     MAILTRANSPORT_DEPRECATED TransportJob *createTransportJob(int transportId);
 
     /**
-      Creates a mail transport job for the given transport identifer,
+      Creates a mail transport job for the given transport identifier,
       or transport name.
       Returns 0 if the specified transport is invalid.
       @param transport A string defining a mail transport.
@@ -179,6 +179,7 @@ public:
 
     /**
       Open a configuration dialog for an existing transport.
+      @param identifier The identifier.
       @param transport The transport to configure.  It can be a new transport,
                        or one already managed by TransportManager.
       @param parent The parent widget for the dialog.
